cwlVersion: v1.2
class: Workflow

doc: |
  This WPS workflow is designed to process ERA5 data, which is 
  usually gathered as two sets of meteorological input grib files,
  atmosphere (3D data) and surface (2D data). This workflow does not 
  include the geogrid step, that will need to be run separately.
  
  Required Inputs:
    * geo_em* input files (generated by geogrid)
    * 2 VTables, atmosphere and surface
    * 2 sets of Grib files, atmosphere and surface
    * 2 ungrib namelist files, atmosphere and surface
    * 1 metgrid namelist file
  
  Returns:
    * met_em* files for a single WRF simulation
  

requirements:
  InlineJavascriptRequirement: {}
  MultipleInputFeatureRequirement: {}


inputs:
  namelist_ungrib_atm:
    label: Configuration File
    type: File
  vtable_atm:
    label: grib variable table
    type: File
  grib_files_atm:
    label: Grib Files
    type:
      type: array
      items: File
  outname_atm: string

  namelist_ungrib_sfc:
    label: Configuration File
    type: File
  vtable_sfc:
    label: grib variable table
    type: File
  grib_files_sfc:
    label: Grib Files
    type:
      type: array
      items: File
  outname_sfc: string

  namelist_metgrid:
    label: metgrid configuration
    type: File
  geo_files:
    label: geogrid data files
    type:
      type: array
      items: File

  generate_metdir: boolean
    
outputs:
  metfiles:
    label: output files
    type:
      type: array
      items: File
    outputSource: step3_metgrid/metfiles


steps:
  step0_metdir:
    run: atmos:cwl/WPS/create_metgrid_dir.cwl
    in:
      generate_metdir: generate_metdir
    out: [metdir]


  step1a_linkgrib_atm:
    run: atmos:cwl/WPS/link_grib_tool.cwl
    in:
      grib_files: grib_files_atm
    out: [grib_dir]

  step1b_linkgrib_sfc:
    run: atmos:cwl/WPS/link_grib_tool.cwl
    in:
      grib_files: grib_files_sfc
    out: [grib_dir]


  step2a_ungrib_atm:
    run: atmos:cwl/WPS/ungrib.cwl
    in:
      namelist: namelist_ungrib_atm
      vtable: vtable_atm
      grib_dir: step1a_linkgrib_atm/grib_dir
      outname: outname_atm
    out: [procfiles]

  step2b_ungrib_sfc:
    run: atmos:cwl/WPS/ungrib.cwl
    in:
      namelist: namelist_ungrib_sfc
      vtable: vtable_sfc
      grib_dir: step1b_linkgrib_sfc/grib_dir
      outname: outname_sfc
    out: [procfiles]


  step3_metgrid:
    run: atmos:cwl/WPS/metgrid.cwl
    in:
      namelist: namelist_metgrid
      geofiles: geo_files
      ungribbed_files_a: step2a_ungrib_atm/procfiles
      ungribbed_files_b: step2b_ungrib_sfc/procfiles
      metdir: step0_metdir/metdir
    out: [metfiles]

$namespaces:
  atmos: https://raw.githubusercontent.com/UoMResearchIT/atmos-tools-library/main/